Learn R Programming

MixTwice (version 2.0)

MixTwice-package: MixTwice

Description

MixTwice

Arguments

Details

The DESCRIPTION file: MixTwice MixTwice

References

Zheng et al. MixTwice: Large scale hypothesis testing for peptide arrays by variance mixing. Bioinformatics, 2021.

Zheng et al. Disordered Antigens and Epitope Overlap Between Anti Citrullinated Protein Antibodies and Rheumatoid Factor in Rheumatoid Arthritis. Arthritis & Rheumatology 72.2 (2020): 262-272.

Examples

Run this code
# NOT RUN {
data(peptide_data)
## For more detail and example, use ?peptide_data and ?mixtwice
# }

Run the code above in your browser using DataLab